@@ -10,7 +10,7 @@
 #    06/23/2016      #5696         rjpeter        Extend CommutativeTimestamp
 ##
 
-from CommutativeTimestamp import CommutativeTimestamp
+from .CommutativeTimestamp import CommutativeTimestamp
 
 # TODO: Remove after 16.4.1 no longer in field
 class FormattedDate(CommutativeTimestamp):
